import Vue from 'vue'
import Vuex from 'vuex'
import API from '@/api'
import { getToken, setToken, removeToken } from '@/utils/auth'
import router, { resetRouter } from '@/router'

// // https://webpack.js.org/guides/dependency-management/#requirecontext
// const modulesFiles = require.context('./modules', true, /\.js$/)

// // you do not need `import app from './modules/app'`
// // it will auto require all vuex module from modules file
// const modules = modulesFiles.keys().reduce((modules, modulePath) => {
//   // set './app.js' => 'app'
//   const moduleName = modulePath.replace(/^\.\/(.*)\.\w+$/, '$1')
//   const value = modulesFiles(modulePath)
//   modules[moduleName] = value.default
//   return modules
// }, {})

Vue.use(Vuex)

const store = new Vuex.Store({
    state: {
        sideBarOpen: false,
        token: getToken(),
        name: '',
    },
    getters: {
        sideBarOpen: state => {
            return state.sideBarOpen
        },
        token: state => state.user.token,
        name: state => state.user.name
    },
    mutations: {
        toggleSidebar (state) {
            state.sideBarOpen = !state.sideBarOpen
        },
        SET_TOKEN: (state, token) => {
            state.token = token
          },
          SET_NAME: (state, name) => {
            state.name = name
          },
    },
    actions: {
        toggleSidebar(context) {
            context.commit('toggleSidebar')
        },
        login({ commit }, userInfo) {
            const { account, password} = userInfo
            return new Promise((resolve, reject) => {
              API.account.login({
                account: account.trim(),
                password,
              }).then(response => {
                const { data } = response
                commit('SET_TOKEN', data.token)
                setToken(data.token)
                resolve()
              }).catch(error => {
                reject(error)
              })
            })
          },
          logout({ commit, state, dispatch }) {
            return new Promise((resolve, reject) => {
              // API.account.logout(state.token).then(() => {
                commit('SET_TOKEN', '')
                commit('SET_NAME', '')
                removeToken()
                resetRouter()
        
                // reset visited views and cached views
                // to fixed https://github.com/PanJiaChen/vue-element-admin/issues/2485
                resolve()
              // }).catch(error => {
              //   reject(error)
              // })
            })
          },
    }
})
export default store
