import axios from 'axios'
 
export default class WebSocketClient {
  constructor(url, apiEndpoint) {
    this.url = url
    this.apiEndpoint = apiEndpoint
    this.socket = null
    this.connected = false
    this.messages = []
    this.error = null
  }
 
  connect() {
    if (this.socket && this.socket.readyState === WebSocket.OPEN) {
      return
    }
    this.socket = new WebSocket(this.url)
 
    this.socket.addEventListener('open', () => {
      console.log('WebSocket connected')
      this.connected = true
      // 连接成功后发送 API 请求
      //this.sendApiRequest()
    })
    this.socket.addEventListener('message', (event) => {
      const message = JSON.parse(event.data)
      //const message = event.data;
      this.messages.push(message)
    })
    this.socket.addEventListener('error', (event) => {
      console.error('WebSocket error:', event)
      this.error = event
    })
    this.socket.addEventListener('close', () => {
      console.log('WebSocket closed')
      this.connected = false
    })
  }
 
  disconnect() {
    if (this.socket) {
      this.socket.close()
    }
  }
 
  sendMessage(message) {
    if (this.socket.readyState !== WebSocket.OPEN) {
      return
    }
    this.socket.send(JSON.stringify(message))
  }
 
  sendApiRequest() {
    axios.get(this.apiEndpoint).then(response => {
      // 处理 API 返回数据并发送给服务端
      const data = response.data
      this.sendMessage(data)
    }).catch(error => {
      console.error('API request error:', error)
    })
  }
}