import axios from 'axios'
import { Message } from 'element-ui'
import { getToken } from '@/utils/auth'
import $router from '@/router'
import { Loading } from 'element-ui'


const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API2, // url = base url + request url
  timeout: 1000 * 60 * 60 * 5 // request timeout
})

// request interceptor
service.interceptors.request.use(
  config => {
    // do something before request is sent
    if (getToken()) {
      // let each request carry token
      // ['X-Token'] is a custom headers key
      // please modify it according to the actual situation
      config.headers['token'] = getToken()
    }
    // 时间
    if (config.params) {
      config.params.nowDate = new Date()
    }
    return config
  },
  error => {
    // do something with request error
    console.log(error) // for debug
    return Promise.reject(error)
  }
)

// response interceptor
service.interceptors.response.use(
  /**
   * If you want to get http information such as headers or status
   * Please return  response => response
   */

  /**
   * Determine the request status by custom code
   * Here is just an example
   * You can also judge the status by HTTP Status Code
   */
  response => {
    const res = response.data
    // console.log(res)

    // if the custom code is not 20000, it is judged as an error.
     if (res.code && res.code !== 200) {
      if (document.getElementsByClassName('el-message').length > 0) {
        // 已经存在不提示
      } else {
        Message({
          message: res.msg || 'Error',
          type: 'error',
          duration: 5 * 1000
        })
      }

      // 50008: Illegal token; 50012: Other clients logged in; 50014: Token expired;
      if (res.code === 401 && res.msg === '登录过期') {
        store.dispatch('user/resetToken').then(() => {
          // location.reload()
          if (location.href.indexOf('#') > -1) {
            const href = location.href.split('#')
            $router.push(`/login?redirect=${href[1]}`)
          } else {
            $router.push(`/login`)
          }
        })
      }
      if (res.code === 10005 || res.code === 10004) { // 10005非法token, 10004用户未登录
        store.dispatch('user/resetToken').then(() => {
          // location.reload()
          if (location.h.indexOf('#') > -1) {
            const href = location.href.split('#')
            $router.push(`/login?redirect=${href[1]}`)
          } else {
            $router.push(`/login`)
          }
        })
      }
      return Promise.reject(new Error(res.msg || 'Error'))
    } else if (response.config.originResponse) {
      return response
    } else {
      return res
    }
  },
  error => {
    if (document.getElementsByClassName('el-message').length > 0) {
      // 已经存在不提示
    } else {
      Message({
        // message: error.message,
        message: '网络错误，请稍后再试！',
        type: 'error',
        duration: 5 * 1000
      })
    }
    return Promise.reject(error)
  }
)

export default service